import { DependencyContainer } from "tsyringe";
import { DatabaseServer } from "@spt/servers/DatabaseServer";
import { IDatabaseTables } from "@spt/models/spt/server/IDatabaseTables";
import { ILogger } from "@spt/models/spt/utils/ILogger";
import { ProfileHandler } from "./profileHandler";

export class DevProfile
{
    private logger: ILogger;
    private dbSrv: DatabaseServer;
    private db: IDatabaseTables;
    private profileHandler: ProfileHandler;

    public constructor()
    {
        this.profileHandler = new ProfileHandler();
    }

    private initialize(container: DependencyContainer): void
    {
        this.logger = container.resolve<ILogger>("WinstonLogger");
        this.dbSrv = container.resolve<DatabaseServer>("DatabaseServer");
        this.db = this.dbSrv.getTables();
    }

    public exampleDev (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "678224eb6b37730561c47a5d";   // Dev use only.
        const profileName = "ExampleProfile";           // The profile name displayed in the launcher
        const profileDescKey = "customprofile-devProfile";  // description-locale-key; will have a use in future updates. Its linked to the content in locale.json

        const gameVersion = this.db.templates.profiles["Edge Of Darkness"]; // Profile to use as base. If you delete ["Edge Of Darkness"] and write [ will appear the options.
        const profileData = "../db/profiles/dev/Example";                   // Your profile files location
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey); // DO NOT EDIT THIS
        this.db.templates.profiles[profileName] = clonedProfile; // DO NOT EDIT THIS TOO
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }
}