import { DependencyContainer } from "tsyringe";
import { DatabaseServer } from "@spt/servers/DatabaseServer";
import { IDatabaseTables } from "@spt/models/spt/server/IDatabaseTables";
import { ILogger } from "@spt/models/spt/utils/ILogger";
import { ProfileHandler } from "./profileHandler";

export class LegacyExpanded
{
    private logger: ILogger;
    private dbSrv: DatabaseServer;
    private db: IDatabaseTables;
    private profileHandler: ProfileHandler;

    public constructor()
    {
        this.profileHandler = new ProfileHandler();
    }

    private initialize(container: DependencyContainer): void
    {
        this.logger = container.resolve<ILogger>("WinstonLogger");
        this.dbSrv = container.resolve<DatabaseServer>("DatabaseServer");
        this.db = this.dbSrv.getTables();
    }

    public expStandard (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6788fafaa574a14122f29cc3"; // Dev use only
        const profileName = "Standard - Store Expanded";
        const profileDescKey = "customprofile-legacy-standard";

        const gameVersion = this.db.templates.profiles["Standard"]
        const profileData = "../db/profiles/legacy/Standard";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public expLeftBehind (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6788fafdc861e49ef73d66fe"; // Dev use only
        const profileName = "Left Behind - Store Expanded";
        const profileDescKey = "customprofile-legacy-leftbehind";

        const gameVersion = this.db.templates.profiles["Left Behind"];
        const profileData = "../db/profiles/legacy/LeftBehind";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;

        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public expPrepareForEscape (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6788fb00dcfcccfe5eea04b8"; // Dev use only
        const profileName = "Prepare for Escape - Store Expanded";
        const profileDescKey = "customprofile-legacy-prepareforescape";

        const gameVersion = this.db.templates.profiles["Prepare To Escape"];
        const profileData = "../db/profiles/legacy/PFE";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public expEdgeOfDarkness (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6788fb04c28745a8c7eea40b"; // Dev use only
        const profileName = "Edge Of Darkness - Store Expanded";
        const profileDescKey = "customprofile-legacy-edgeofdarkness";

        const gameVersion = this.db.templates.profiles["Edge Of Darkness"];
        const profileData = "../db/profiles/legacy/EOD";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public expTheUnheard (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6788fb07d1f65e724c6d932e"; // Dev use only
        const profileName = "The Unheard - Store Expanded";
        const profileDescKey = "customprofile-legacy-unheard";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/legacy/Unheard";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;

        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }
}
