import { DependencyContainer } from "tsyringe";
import { DatabaseServer } from "@spt/servers/DatabaseServer";
import { IDatabaseTables } from "@spt/models/spt/server/IDatabaseTables";
import { ILogger } from "@spt/models/spt/utils/ILogger";
import { ProfileHandler } from "./profileHandler";

export class MainProfiles
{
    private logger: ILogger;
    private dbSrv: DatabaseServer;
    private db: IDatabaseTables;
    private profileHandler: ProfileHandler;

    public constructor()
    {
        this.profileHandler = new ProfileHandler();
    }

    private initialize(container: DependencyContainer): void
    {
        this.logger = container.resolve<ILogger>("WinstonLogger");
        this.dbSrv = container.resolve<DatabaseServer>("DatabaseServer");
        this.db = this.dbSrv.getTables();
    }

    public sof5Base (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "678224eb6b37730561c47a5d"; // Dev use only
        const profileName = "Special Operations Forces '5'";
        const profileDescKey = "customprofile-shadowxtrex-sof5b";

        const gameVersion = this.db.templates.profiles["Edge Of Darkness"];
        const profileData = "../db/profiles/main/SOF/5/Base";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public sof5Plus (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "67824b467933efd1a2d9672d"; // Dev use only
        const profileName = "Special Operations Forces '5' Plus";
        const profileDescKey = "customprofile-shadowxtrex-sof5p";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/main/SOF/5/Plus";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;

        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public sof5Merged (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "67824b487413b0d346aaeab9"; // Dev use only
        const profileName = "Special Operations Forces '5' Merged";
        const profileDescKey = "customprofile-shadowxtrex-sof5m";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/main/SOF/5/Merged";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public sof7Base (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "67825015b8d3152d0c41ec33"; // Dev use only
        const profileName = "Special Operations Forces '7'";
        const profileDescKey = "customprofile-shadowxtrex-sof7b";

        const gameVersion = this.db.templates.profiles["Edge Of Darkness"];
        const profileData = "../db/profiles/main/SOF/7/Base";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public sof7Plus (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "678250193fb544c7b882aa20"; // Dev use only
        const profileName = "Special Operations Forces '7' Plus";
        const profileDescKey = "customprofile-shadowxtrex-sof7p";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/main/SOF/7/Plus";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;

        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public sof7Merged (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6782501d19fc82f1c5bc09e6"; // Dev use only
        const profileName = "Special Operations Forces '7' Merged";
        const profileDescKey = "customprofile-shadowxtrex-sof7m";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/main/SOF/7/Merged";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public worseThan (container: DependencyContainer): void
    {

        this.initialize(container);

        const profileID = "67825491788331e80a86844c"; // Dev use only
        const profileName = "Worse Than";
        const profileDescKey = "customprofile-shadowxtrex-sof7m";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/main/WorseThan";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }
}
