import path from "node:path"
import { DependencyContainer } from "tsyringe";
import { IPostDBLoadMod } from "@spt/models/external/IPostDBLoadMod";
import { VFS } from "@spt/utils/VFS";

import { MainProfiles } from "./mainProfiles";
import { CustomRequested } from "./requestedProfiles";
import { LegacyExpanded } from "./legacyExpanded"
import { DevProfile } from "./devProfile";

import { jsonc } from "jsonc";

class ProfileLoader implements IPostDBLoadMod
{
    private container: DependencyContainer;
    private mainProfiles: MainProfiles;
    private customRequested: CustomRequested; 
    private legacyExpanded: LegacyExpanded;
    private devProfile: DevProfile;
    private vfs: VFS;
    
    public postDBLoad(container: DependencyContainer): void
    {
        this.vfs = container.resolve<VFS>("VFS");
        this.container = container;
        this.mainProfiles = new MainProfiles();
        this.customRequested = new CustomRequested();
        this.legacyExpanded = new LegacyExpanded();
        this.devProfile = new DevProfile();

        const config = jsonc.parse(this.vfs.readFile(path.resolve(__dirname, "../config/config.jsonc")));

        if (config.mainProfiles.SOF5.SOF5_Base)         this.mainProfiles.sof5Base(this.container);
        if (config.mainProfiles.SOF5.SOF5_Plus)         this.mainProfiles.sof5Plus(this.container);
        if (config.mainProfiles.SOF5.SOF5_Merged)       this.mainProfiles.sof5Merged(this.container);

        if (config.mainProfiles.SOF7.SOF7_Base)         this.mainProfiles.sof7Base(this.container)
        if (config.mainProfiles.SOF7.SOF7_Plus)         this.mainProfiles.sof7Plus(this.container);
        if (config.mainProfiles.SOF7.SOF7_Merged)       this.mainProfiles.sof7Merged(this.container);

        if (config.mainProfiles.WorseThan)              this.mainProfiles.worseThan(this.container);

        if (config.customProfiles.Rocky_Standard)       this.customRequested.stdRocky(this.container);

        if (config.customProfiles.GC_Kronzky)           this.customRequested.gigachadKronzky(this.container);

        if (config.customProfiles.GC_KushJones)         this.customRequested.gigachadKushJones(this.container);

        if (config.customProfiles.SOF7_Tabi)            this.customRequested.sof7Tabi(this.container);
        if (config.customProfiles.Tabi_Standard)        this.customRequested.stdTabi(this.container);

        if (config.customProfiles.ZTH_TASBot)           this.customRequested.zthTASBot(this.container);

        if (config.customProfiles.ZTH_Gray404)          this.customRequested.zthGray404(this.container);
        
        if (config.customProfiles.ZTH_Jed16338)         this.customRequested.zthJed16338(this.container);
        
        if (config.customProfiles.BareBones_VixeusVii)  this.customRequested.zthVixeusVii(this.container);

        if (config.customProfiles.ShadowXtrex_PVE)      this.customRequested.unhShadowXtrex(this.container);

        if (config.LegacyPlus.Standard_exp)             this.legacyExpanded.expStandard(this.container);
        if (config.LegacyPlus.LB_exp)                   this.legacyExpanded.expLeftBehind(this.container);
        if (config.LegacyPlus.PFE_exp)                  this.legacyExpanded.expPrepareForEscape(this.container);
        if (config.LegacyPlus.EOD_exp)                  this.legacyExpanded.expEdgeOfDarkness(this.container);
        if (config.LegacyPlus.Unheard_exp)              this.legacyExpanded.expTheUnheard(this.container);

        if (config.devProfiles)                         this.devProfile.exampleDev(this.container);
        
    }
}

export const mod = new ProfileLoader();