import { DependencyContainer } from "tsyringe";
import { DatabaseServer } from "@spt/servers/DatabaseServer";
import { IDatabaseTables } from "@spt/models/spt/server/IDatabaseTables";
import { ILogger } from "@spt/models/spt/utils/ILogger";
import { ProfileHandler } from "./profileHandler";

export class CustomRequested
{
    private logger: ILogger;
    private dbSrv: DatabaseServer;
    private db: IDatabaseTables;
    private profileHandler: ProfileHandler;

    public constructor()
    {
        this.profileHandler = new ProfileHandler();
    }

    private initialize(container: DependencyContainer): void
    {
        this.logger = container.resolve<ILogger>("WinstonLogger");
        this.dbSrv = container.resolve<DatabaseServer>("DatabaseServer");
        this.db = this.dbSrv.getTables();
    }

    public stdRocky (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6782778403f4ff37f4fa2d71"; // Dev use only
        const profileName = "Rocky's Standard 2025";
        const profileDescKey = "customprofile-rocky-standard";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/ItsRock/RockysStandard";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public gigachadKronzky (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "67827774d1f15f9bd4dde685"; // Dev use only
        const profileName = "Gigachad by Kronzky";
        const profileDescKey = "customprofile-kronzky-gigachad";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/custom/Kronzky/Gigachad";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public gigachadKushJones (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6782777785b507b5996b0641"; // Dev use only
        const profileName = "Gigachad by KushJones";
        const profileDescKey = "customprofile-kushjones-gigachad";

        const gameVersion = this.db.templates.profiles["Unheard"];
        const profileData = "../db/profiles/custom/KushJones/Gigachad";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;

        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public sof7Tabi (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6782778bd39d74dcc547bc5d"; // Dev use only
        const profileName = "Special Operations Forces '7' Tabi";
        const profileDescKey = "customprofile-tabi-sof7";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/Tabi/SOF7";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public stdTabi (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "678277923647524a290a0d93"; // Dev use only
        const profileName = "Tabi's Standard";
        const profileDescKey = "customprofile-tabi-standard";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/Tabi/Standard";
        
        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;

        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public zthTASBot (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6782779b2ceaec16fd953f28"; // Dev use only
        const profileName = "Zero to Hero by TASBot";
        const profileDescKey = "customprofile-TASBot-ZeroToHero";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/TASBot/ZeroToHero";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public zthGray404 (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6783b09b846c2e0a90e61aa6"; // Dev use only
        const profileName = "Zero to Hero by Gray404";
        const profileDescKey = "customprofile-Gray404-ZeroToHero";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/Gray404/ZeroToHero";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public zthJed16338 (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6783b09ff42b030ea05f2f8b"; // Dev use only
        const profileName = "Zero to Hero by Jed16338";
        const profileDescKey = "customprofile-Jed16338-ZeroToHero";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/Jed16338/ZeroToHero";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public zthVixeusVii (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6783b0a4aa442f995fd68699"; // Dev use only
        const profileName = "BareBones by VixeusVii";
        const profileDescKey = "customprofile-VixeusVii-BareBones";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/VixeusVii/BareBones";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }

    public unhShadowXtrex (container: DependencyContainer): void
    {
        this.initialize(container);

        const profileID = "6789096174e0a74c00fa7e9d"; // Dev use only
        const profileName = "ShadowXtrex Unheard from PVE";
        const profileDescKey = "customprofile-shadowxtrex-pve";

        const gameVersion = this.db.templates.profiles["Standard"];
        const profileData = "../db/profiles/custom/ShadowXtrex/PVE";

        const clonedProfile = this.profileHandler.cloneProfile(gameVersion, profileName, profileData, profileDescKey);
        this.db.templates.profiles[profileName] = clonedProfile;
        
        this.logger.success(`Added profile [${profileID}] as [${profileName}] to the database`);
    }
    
}